@@ -1,6 +1,6 @@
 ##
 ## intsurv: Integrative Survival Models
-## Copyright (C) 2017-2021  Wenjie Wang <wang@wwenjie.org>
+## Copyright (C) 2017-2025  Wenjie Wang <wang@wwenjie.org>
 ##
 ## This file is part of the R package intsurv.
 ##
@@ -93,7 +93,23 @@ coef.cox_cure <- function(object, part = c("both", "survival", "cure"), ...)
 ##' @rdname coef.cox_cure
 ##' @method coef cox_cure_uncer
 ##' @export
-coef.cox_cure_uncer <- coef.cox_cure
+coef.cox_cure_uncer <- function(object,
+                                part = c("both", "survival", "cure"),
+                                ...)
+{
+    part <- match.arg(part)
+    if (part != "both") {
+        coef_name <- sprintf(
+            "%s_coef", switch(part,
+                              "survival" = "surv",
+                              "cure" = "cure")
+        )
+        return(object[[coef_name]])
+    }
+    ## else return both
+    list(surv = object$surv_coef,
+         cure = object$cure_coef)
+}
 
 
 ##' Estimated Covariate Coefficients
@@ -102,9 +118,6 @@ coef.cox_cure_uncer <- coef.cox_cure
 ##' regularized Cox cure rate model.
 ##'
 ##' @param object Object representing a fitted solution path.
-##' @param naive_en A logical value specifying whether to return naive elastic
-##'     net estimates.  If \code{FALSE} by default, the elastic net estimates
-##'     will be returned instead of the naive elastic net estimates.
 ##' @param selection A character string for specifying the criterion for
 ##'     selection of coefficient estimates.  The available options are
 ##'     \code{"bic1"} for selecting coefficient estimates by regular BIC
@@ -131,19 +144,17 @@ coef.cox_cure_uncer <- coef.cox_cure
 ##' @importFrom stats coef
 ##' @method coef cox_cure_net
 ##' @export
-coef.cox_cure_net <- function(object, naive_en = FALSE,
+coef.cox_cure_net <- function(object,
                               selection = c("bic1", "bic2", "all"), ...)
 {
     bic <- match.arg(selection)
-    surv_coef_name <- paste0("surv_", ifelse(naive_en, "", "en_"), "coef")
-    cure_coef_name <- paste0("cure_", ifelse(naive_en, "", "en_"), "coef")
     if (bic != "all") {
         idx <- which.min(object$model[[bic]])
-        out <- list(surv = object[[surv_coef_name]][idx, ],
-                    cure = object[[cure_coef_name]][idx, ])
+        out <- list(surv = object$surv_coef[idx, ],
+                    cure = object$cure_coef[idx, ])
     } else {
-        out <- list(surv = object[[surv_coef_name]],
-                    cure = object[[cure_coef_name]])
+        out <- list(surv = object$surv_coef,
+                    cure = object$cure_coef)
     }
     ## return
     out
