@@ -1,6 +1,6 @@
 ##
 ## intsurv: Integrative Survival Models
-## Copyright (C) 2017-2021  Wenjie Wang <wang@wwenjie.org>
+## Copyright (C) 2017-2025  Wenjie Wang <wang@wwenjie.org>
 ##
 ## This file is part of the R package intsurv.
 ##
@@ -20,16 +20,18 @@
 ##' @export
 print.cox_cure <- function(x, ...)
 {
-    ## function call
-    cat("Call:\n", paste(deparse(x$call), sep = "\n", collapse = "\n"),
-        "\n", sep = "")
+    if (! is.null(x$call)) {
+        ## function call
+        cat("Call:\n", paste(deparse(x$call), sep = "\n", collapse = "\n"),
+            "\n", sep = "")
+    }
     ## get the coef matrix
     obj <- summary.cox_cure(x)
     ## survival part
-    cat("\nCoefficient estimates from the survival part:\n\n")
+    cat("\nCoefficient estimates for the survival part:\n\n")
     printCoefmat(obj$surv_coef_mat)
     ## cure rate part
-    cat("\nCoefficient estimates from the cure rate part:\n\n")
+    cat("\nCoefficient estimates for the cure rate part:\n\n")
     printCoefmat(obj$cure_coef_mat)
     ## return
     invisible(x)
@@ -40,16 +42,18 @@ print.cox_cure <- function(x, ...)
 ##' @export
 print.cox_cure_uncer <- function(x, ...)
 {
-    ## function call
-    cat("Call:\n", paste(deparse(x$call), sep = "\n", collapse = "\n"),
-        "\n", sep = "")
+    if (! is.null(x$call)) {
+        ## function call
+        cat("Call:\n", paste(deparse(x$call), sep = "\n", collapse = "\n"),
+            "\n", sep = "")
+    }
     ## get the coef matrix
     obj <- summary.cox_cure_uncer(x)
     ## survival part
-    cat("\nCoefficient estimates from the survival part:\n\n")
+    cat("\nCoefficient estimates for the survival part:\n\n")
     printCoefmat(obj$surv_coef_mat)
     ## cure rate part
-    cat("\nCoefficient estimates from the cure rate part:\n\n")
+    cat("\nCoefficient estimates for the cure rate part:\n\n")
     printCoefmat(obj$cure_coef_mat)
     ## return
     invisible(x)
@@ -60,14 +64,16 @@ print.cox_cure_uncer <- function(x, ...)
 ##' @export
 print.summary_cox_cure <- function(x, ...)
 {
-    ## function call
-    cat("Call:\n", paste(deparse(x$call), sep = "\n", collapse = "\n"),
-        "\n", sep = "")
+    if (! is.null(x$call)) {
+        ## function call
+        cat("Call:\n", paste(deparse(x$call), sep = "\n", collapse = "\n"),
+            "\n", sep = "")
+    }
     ## survival coef
-    cat("\nCoefficient estimates from the survival part:\n\n")
+    cat("\nCoefficient estimates for the survival part:\n\n")
     printCoefmat(x$surv_coef_mat)
     ## cure coef
-    cat("\nCoefficient estimates from the cure rate part:\n\n")
+    cat("\nCoefficient estimates for the cure rate part:\n\n")
     printCoefmat(x$cure_coef_mat)
     ## misc
     cat(sprintf("\nNumber of observations: %d\n", x$model$nObs))
@@ -81,7 +87,6 @@ print.summary_cox_cure <- function(x, ...)
 }
 
 
-## TODO: customize more for cox_cure_uncer
 ##' @method print summary_cox_cure_uncer
 ##' @export
 print.summary_cox_cure_uncer <- print.summary_cox_cure
@@ -91,9 +96,11 @@ print.summary_cox_cure_uncer <- print.summary_cox_cure
 ##' @export
 print.cox_cure_net <- function(x, ...)
 {
-    ## function call
-    cat("Call:\n", paste(deparse(x$call), sep = "\n", collapse = "\n"),
-        "\n\n", sep = "")
+    if (! is.null(x$call)) {
+        ## function call
+        cat("Call:\n", paste(deparse(x$call), sep = "\n", collapse = "\n"),
+            "\n\n", sep = "")
+    }
     bic_dat <- BIC.cox_cure_net(x)
     digits <- max(3, getOption("digits") - 3)
     lambda_dat <- as.data.frame(signif(x$penalty$lambda_mat, digits))
